---
label: MOUNTAINSORT4
dockerfile: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/mountainsort4/container/Dockerfile
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/mountainsort4/mountainsort4.py
website: https://github.com/flatironinstitute/mountainsort_examples/blob/master/README.md
source_code: https://github.com/magland/ml_ephys
authors: Jeremy Magland, Alex Barnett, Jason Chung, Loren Frank, and Leslie Greengard
processor_name: MountainSort4
doi: 10.1016/j.neuron.2017.08.030
---
_
# MOUNTAINSORT4

## Description

MountainSort is spike sorting algorithm that uses a novel density-based clustering method called ISO-SPLIT.

## References

Chung, J. E., Magland, J. F., Barnett, A. H., Tolosa, V. M., Tooker, A. C., Lee, K. Y., ... & Greengard, L. F. (2017). A fully automated approach to spike sorting. Neuron, 95(6), 1381-1394.